Index: Source/core/workers/SharedWorkerGlobalScope.h |
diff --git a/Source/core/workers/SharedWorkerContext.h b/Source/core/workers/SharedWorkerGlobalScope.h |
similarity index 73% |
rename from Source/core/workers/SharedWorkerContext.h |
rename to Source/core/workers/SharedWorkerGlobalScope.h |
index b87f849da788690c8e891e0771b0e1034b90e3d0..1d4a48ff7048198260b7c2843587debe0022089e 100644 |
--- a/Source/core/workers/SharedWorkerContext.h |
+++ b/Source/core/workers/SharedWorkerGlobalScope.h |
@@ -28,36 +28,36 @@ |
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
*/ |
-#ifndef SharedWorkerContext_h |
-#define SharedWorkerContext_h |
+#ifndef SharedWorkerGlobalScope_h |
+#define SharedWorkerGlobalScope_h |
#include "core/page/ContentSecurityPolicy.h" |
-#include "core/workers/WorkerContext.h" |
+#include "core/workers/WorkerGlobalScope.h" |
namespace WebCore { |
class MessageEvent; |
class SharedWorkerThread; |
- class SharedWorkerContext : public WorkerContext { |
+ class SharedWorkerGlobalScope : public WorkerGlobalScope { |
public: |
- typedef WorkerContext Base; |
- static PassRefPtr<SharedWorkerContext> create(const String& name, const KURL&, const String& userAgent, SharedWorkerThread*, const String& contentSecurityPolicy, ContentSecurityPolicy::HeaderType contentSecurityPolicyType); |
- virtual ~SharedWorkerContext(); |
+ typedef WorkerGlobalScope Base; |
+ static PassRefPtr<SharedWorkerGlobalScope> create(const String& name, const KURL&, const String& userAgent, SharedWorkerThread*, const String& contentSecurityPolicy, ContentSecurityPolicy::HeaderType contentSecurityPolicyType); |
+ virtual ~SharedWorkerGlobalScope(); |
- virtual bool isSharedWorkerContext() const OVERRIDE { return true; } |
+ virtual bool isSharedWorkerGlobalScope() const OVERRIDE { return true; } |
// EventTarget |
virtual const AtomicString& interfaceName() const OVERRIDE; |
// Setters/Getters for attributes in SharedWorkerContext.idl |
DEFINE_ATTRIBUTE_EVENT_LISTENER(connect); |
String name() const { return m_name; } |
SharedWorkerThread* thread(); |
private: |
- SharedWorkerContext(const String& name, const KURL&, const String& userAgent, SharedWorkerThread*); |
+ SharedWorkerGlobalScope(const String& name, const KURL&, const String& userAgent, SharedWorkerThread*); |
virtual void logExceptionToConsole(const String& errorMessage, const String& sourceURL, int lineNumber, PassRefPtr<ScriptCallStack>) OVERRIDE; |
String m_name; |
@@ -67,4 +67,4 @@ namespace WebCore { |
} // namespace WebCore |
-#endif // SharedWorkerContext_h |
+#endif // SharedWorkerGlobalScope_h |
@@ -28,36 +28,36 @@ |
// EventTarget |
virtual const AtomicString& interfaceName() const OVERRIDE; |
- // Setters/Getters for attributes in SharedWorkerContext.idl |
+ // Setters/Getters for attributes in SharedWorkerGlobalScope.idl |
DEFINE_ATTRIBUTE_EVENT_LISTENER(connect); |
String name() const { return m_name; } |